#include <stdio.h>

#define FIM 0
#define HABITANTES 501

void mflush(void);
float calc_salarioMedio (float [][4]);
int calc_mulheres (float [][4]);
float calc_idades (float [][4], int *, int *);

/***************************
 * Programa principal
 ***************************
 */

int main (void) 
{

  /* Matriz popul[][]:
       COL1 == idade
       COL2 == sexo
       COL3 == salario
       COL4 == filhos
  */
  float popul[HABITANTES][4],
        idade_media;
  int id,
      idade_max,
      idade_min,
      hab = 0;

  do {
    printf ("Entre dados do habitante:\n");
    printf ("\t idade: ");
    scanf ("%d", &id);
    mflush();
    if (id != FIM) { 
      popul[hab][0] = id;
      printf ("\t sexo: ");
      scanf ("%c", &popul[hab][1]);
      if (popul[hab][1] != 'f' && popul[hab][1] != 'F' && 
	  popul[hab][1] != 'm' && popul[hab][1] != 'M') {
	printf ("\t\t Sexo deve ser M, m, F ou f\n");
	mflush();
	continue;
      }
      printf ("\t salario: ");
      scanf ("%f", &popul[hab][2]);
      printf ("\t filhos: ");
      scanf ("%d", &popul[hab][3]);
      hab++;
    }
  } while (id != FIM && hab < HABITANTES);
  
  popul[hab][0] = popul[hab][1] = popul[hab][2] = popul[hab][3] = -1;
  
  if (hab) {
    idade_media = calc_idades(popul, &idade_max, &idade_min);
    
    printf ("MEDIA SALARIAL = %f\n", calc_salarioMedio (popul));
    printf ("IDADES: max = %d, min = %d, media = %f\n", 
	    idade_max, idade_min, idade_media);
    printf ("Mulheres com 3 filhos e renda ate' R$500,00 = %d\n", 
	    calc_mulheres(popul));
  }
}

/**********************************************************************
 *  Funcao calc_salarioMedio
 * 
 *  Acao:       Calcula salario medio de um conjunto de habitantes de
 *              uma cidade
 *  Entrada:    vetor com todos os salarios coletados
 *  Saida:      salario medio
 *  Suposicoes: Ultimo elemento do vetor tem valor -1, que deve ser
 *              desconsiderado no calculo da media
 *  Algoritmo:  Soma todos os elementos do vetor (exceto o ultimo) e
 *              divide o resultado pelo numero de elementos
 **********************************************************************
 */
float calc_salarioMedio (float pop[][4])
{
  float media = 0;
  int i;
  
  for (i = 0; pop[i][2] != -1; i++) 
    media += pop[i][2];

  return (media / i);

}

/**********************************************************************
 *  Funcao calc_idades
 * 
 *  Acao:       Calcula idade media, maxima e minima de um conjunto de
 *              habitantes de uma cidade
 *  Entrada:    vetor com as idades coletadas
 *  Saida:      salario medio (retorno)
 *              idade maxima e minima (por referencia)
 *  Suposicoes: Ultimo elemento do vetor tem valor -1, que deve ser
 *              desconsiderado nos calculos
 *  Algoritmo:  Soma todos os elementos do vetor (exceto o ultimo) e
 *              divide o resultado pelo numero de elementos.
 *              Enquanto soma, calcula maior e menor idade.
 **********************************************************************
 */
float calc_idades (float pop[][4], int *max, int *min)
{
  float media;
  int i;

  for (media = i = 0, *max = *min = pop[0][0]; pop[i][0] != -1; i++) {
    media += pop[i][0];

    if (*max < pop[i][0]) 
      *max = pop[i][0];
    else if (*min > pop[i][0])
      *min = pop[i][0];
  }

  return (media / i);

}

/**********************************************************************
 *  Funcao calc_mulheres
 * 
 *  Acao:       Calcula quantidade de mulheres com 3 filhos e salario
 *              ateh R$ 500,00
 *  Entrada:    vetores com numero de filhos, salarios e sexos
 *              coletados
 *  Saida:      quantidade de mulheres que obedecem aos criterios.
 *  Suposicoes: Ultimo elemento de cada vetor tem valor -1, que deve
 *              ser desconsiderado nos calculos
 **********************************************************************
 */
int calc_mulheres (float pop[][4])
{
  int i,
      mulheres;

  for (mulheres = i = 0; pop[i][3] != -1; i++) {
    if ((pop[i][1] == 'F' || pop[i][1] == 'f') && 
	pop[i][3] == 3 && pop[i][2] <= 500.00)
      ++mulheres;
  }

  return mulheres;
}

/**********************************************************************
 *  Funcao mflush
 * 
 *  Acao:       esvazia buffer de entrada
 *  Entrada:    nenhuma
 *  Saida:      nenhuma
 **********************************************************************
 */
void mflush()
{
  while (getchar() != '\n');
}

